@@ -1,4 +1,5 @@
 import json
+from typing import Optional
 
 from moto.core.exceptions import JsonRESTError
 
@@ -8,7 +9,7 @@ class IoTClientError(JsonRESTError):
 
 
 class ResourceNotFoundException(IoTClientError):
-    def __init__(self, msg=None):
+    def __init__(self, msg: Optional[str] = None):
         self.code = 404
         super().__init__(
             "ResourceNotFoundException", msg or "The specified resource does not exist"
@@ -16,13 +17,13 @@ class ResourceNotFoundException(IoTClientError):
 
 
 class InvalidRequestException(IoTClientError):
-    def __init__(self, msg=None):
+    def __init__(self, msg: Optional[str] = None):
         self.code = 400
         super().__init__("InvalidRequestException", msg or "The request is not valid.")
 
 
 class InvalidStateTransitionException(IoTClientError):
-    def __init__(self, msg=None):
+    def __init__(self, msg: Optional[str] = None):
         self.code = 409
         super().__init__(
             "InvalidStateTransitionException",
@@ -31,7 +32,7 @@ class InvalidStateTransitionException(IoTClientError):
 
 
 class VersionConflictException(IoTClientError):
-    def __init__(self, name):
+    def __init__(self, name: str):
         self.code = 409
         super().__init__(
             "VersionConflictException",
@@ -40,19 +41,19 @@ class VersionConflictException(IoTClientError):
 
 
 class CertificateStateException(IoTClientError):
-    def __init__(self, msg, cert_id):
+    def __init__(self, msg: str, cert_id: str):
         self.code = 406
         super().__init__("CertificateStateException", f"{msg} Id: {cert_id}")
 
 
 class DeleteConflictException(IoTClientError):
-    def __init__(self, msg):
+    def __init__(self, msg: str):
         self.code = 409
         super().__init__("DeleteConflictException", msg)
 
 
 class ResourceAlreadyExistsException(IoTClientError):
-    def __init__(self, msg, resource_id, resource_arn):
+    def __init__(self, msg: str, resource_id: str, resource_arn: str):
         self.code = 409
         super().__init__(
             "ResourceAlreadyExistsException", msg or "The resource already exists."
@@ -67,7 +68,7 @@ class ResourceAlreadyExistsException(IoTClientError):
 
 
 class VersionsLimitExceededException(IoTClientError):
-    def __init__(self, name):
+    def __init__(self, name: str):
         self.code = 409
         super().__init__(
             "VersionsLimitExceededException",
@@ -76,7 +77,7 @@ class VersionsLimitExceededException(IoTClientError):
 
 
 class ThingStillAttached(IoTClientError):
-    def __init__(self, name):
+    def __init__(self, name: str):
         self.code = 409
         super().__init__(
             "InvalidRequestException",
